==> appmesh-1.93.0-sources.jar: software/amazon/awscdk/services/appmesh/AccessLogConfig.java <==
package software.amazon.awscdk.services.appmesh;

/**
 * (experimental) All Properties for Envoy Access logs for mesh endpoints.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.24.0 (build b722f66)", date = "2021-03-11T13:47:05.055Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.appmesh.$Module.class, fqn = "@aws-cdk/aws-appmesh.AccessLogConfig")
@software.amazon.jsii.Jsii.Proxy(AccessLogConfig.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
public interface AccessLogConfig extends software.amazon.jsii.JsiiSerializable {

    /**
     * (experimental) VirtualGateway CFN configuration for Access Logging.
     * <p>
     * Default: - no access logging
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    default @org.jetbrains.annotations.Nullable software.amazon.awscdk.services.appmesh.CfnVirtualGateway.VirtualGatewayAccessLogProperty getVirtualGatewayAccessLog() {
        return null;
    }

    /**
     * (experimental) VirtualNode CFN configuration for Access Logging.
     * <p>
     * Default: - no access logging
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    default @org.jetbrains.annotations.Nullable software.amazon.awscdk.services.appmesh.CfnVirtualNode.AccessLogProperty getVirtualNodeAccessLog() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link AccessLogConfig}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link AccessLogConfig}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public static final class Builder implements software.amazon.jsii.Builder<AccessLogConfig> {
        private software.amazon.awscdk.services.appmesh.CfnVirtualGateway.VirtualGatewayAccessLogProperty virtualGatewayAccessLog;
        private software.amazon.awscdk.services.appmesh.CfnVirtualNode.AccessLogProperty virtualNodeAccessLog;

        /**
         * Sets the value of {@link AccessLogConfig#getVirtualGatewayAccessLog}
         * @param virtualGatewayAccessLog VirtualGateway CFN configuration for Access Logging.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder virtualGatewayAccessLog(software.amazon.awscdk.services.appmesh.CfnVirtualGateway.VirtualGatewayAccessLogProperty virtualGatewayAccessLog) {
            this.virtualGatewayAccessLog = virtualGatewayAccessLog;
            return this;
        }

        /**
         * Sets the value of {@link AccessLogConfig#getVirtualNodeAccessLog}
         * @param virtualNodeAccessLog VirtualNode CFN configuration for Access Logging.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder virtualNodeAccessLog(software.amazon.awscdk.services.appmesh.CfnVirtualNode.AccessLogProperty virtualNodeAccessLog) {
            this.virtualNodeAccessLog = virtualNodeAccessLog;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link AccessLogConfig}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        @Override
        public AccessLogConfig build() {
            return new Jsii$Proxy(virtualGatewayAccessLog, virtualNodeAccessLog);
        }
    }

    /**
     * An implementation for {@link AccessLogConfig}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements AccessLogConfig {
        private final software.amazon.awscdk.services.appmesh.CfnVirtualGateway.VirtualGatewayAccessLogProperty virtualGatewayAccessLog;
        private final software.amazon.awscdk.services.appmesh.CfnVirtualNode.AccessLogProperty virtualNodeAccessLog;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.virtualGatewayAccessLog = software.amazon.jsii.Kernel.get(this, "virtualGatewayAccessLog", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.appmesh.CfnVirtualGateway.VirtualGatewayAccessLogProperty.class));
            this.virtualNodeAccessLog = software.amazon.jsii.Kernel.get(this, "virtualNodeAccessLog", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.appmesh.CfnVirtualNode.AccessLogProperty.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final software.amazon.awscdk.services.appmesh.CfnVirtualGateway.VirtualGatewayAccessLogProperty virtualGatewayAccessLog, final software.amazon.awscdk.services.appmesh.CfnVirtualNode.AccessLogProperty virtualNodeAccessLog) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.virtualGatewayAccessLog = virtualGatewayAccessLog;
            this.virtualNodeAccessLog = virtualNodeAccessLog;
        }

        @Override
        public final software.amazon.awscdk.services.appmesh.CfnVirtualGateway.VirtualGatewayAccessLogProperty getVirtualGatewayAccessLog() {
            return this.virtualGatewayAccessLog;
        }

        @Override
        public final software.amazon.awscdk.services.appmesh.CfnVirtualNode.AccessLogProperty getVirtualNodeAccessLog() {
            return this.virtualNodeAccessLog;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            if (this.getVirtualGatewayAccessLog() != null) {
                data.set("virtualGatewayAccessLog", om.valueToTree(this.getVirtualGatewayAccessLog()));
            }
            if (this.getVirtualNodeAccessLog() != null) {
                data.set("virtualNodeAccessLog", om.valueToTree(this.getVirtualNodeAccessLog()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@aws-cdk/aws-appmesh.AccessLogConfig"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            AccessLogConfig.Jsii$Proxy that = (AccessLogConfig.Jsii$Proxy) o;

            if (this.virtualGatewayAccessLog != null ? !this.virtualGatewayAccessLog.equals(that.virtualGatewayAccessLog) : that.virtualGatewayAccessLog != null) return false;
            return this.virtualNodeAccessLog != null ? this.virtualNodeAccessLog.equals(that.virtualNodeAccessLog) : that.virtualNodeAccessLog == null;
        }

        @Override
        public final int hashCode() {
            int result = this.virtualGatewayAccessLog != null ? this.virtualGatewayAccessLog.hashCode() : 0;
            result = 31 * result + (this.virtualNodeAccessLog != null ? this.virtualNodeAccessLog.hashCode() : 0);
            return result;
        }
    }
}

==> appmesh-1.182.0-sources.jar: software/amazon/awscdk/services/appmesh/AccessLogConfig.java <==
package software.amazon.awscdk.services.appmesh;

/**
 * All Properties for Envoy Access logs for mesh endpoints.
 * <p>
 * Example:
 * <p>
 * <blockquote><pre>
 * // The code below shows an example of how to instantiate this type.
 * // The values are placeholders you should change.
 * import software.amazon.awscdk.services.appmesh.*;
 * AccessLogConfig accessLogConfig = AccessLogConfig.builder()
 *         .virtualGatewayAccessLog(VirtualGatewayAccessLogProperty.builder()
 *                 .file(VirtualGatewayFileAccessLogProperty.builder()
 *                         .path("path")
 *                         // the properties below are optional
 *                         .format(LoggingFormatProperty.builder()
 *                                 .json(List.of(JsonFormatRefProperty.builder()
 *                                         .key("key")
 *                                         .value("value")
 *                                         .build()))
 *                                 .text("text")
 *                                 .build())
 *                         .build())
 *                 .build())
 *         .virtualNodeAccessLog(AccessLogProperty.builder()
 *                 .file(FileAccessLogProperty.builder()
 *                         .path("path")
 *                         // the properties below are optional
 *                         .format(LoggingFormatProperty.builder()
 *                                 .json(List.of(JsonFormatRefProperty.builder()
 *                                         .key("key")
 *                                         .value("value")
 *                                         .build()))
 *                                 .text("text")
 *                                 .build())
 *                         .build())
 *                 .build())
 *         .build();
 * </pre></blockquote>
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.71.0 (build f1f58ae)", date = "2022-12-07T17:24:46.015Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.appmesh.$Module.class, fqn = "@aws-cdk/aws-appmesh.AccessLogConfig")
@software.amazon.jsii.Jsii.Proxy(AccessLogConfig.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface AccessLogConfig extends software.amazon.jsii.JsiiSerializable {

    /**
     * VirtualGateway CFN configuration for Access Logging.
     * <p>
     * Default: - no access logging
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable software.amazon.awscdk.services.appmesh.CfnVirtualGateway.VirtualGatewayAccessLogProperty getVirtualGatewayAccessLog() {
        return null;
    }

    /**
     * VirtualNode CFN configuration for Access Logging.
     * <p>
     * Default: - no access logging
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable software.amazon.awscdk.services.appmesh.CfnVirtualNode.AccessLogProperty getVirtualNodeAccessLog() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link AccessLogConfig}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link AccessLogConfig}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<AccessLogConfig> {
        software.amazon.awscdk.services.appmesh.CfnVirtualGateway.VirtualGatewayAccessLogProperty virtualGatewayAccessLog;
        software.amazon.awscdk.services.appmesh.CfnVirtualNode.AccessLogProperty virtualNodeAccessLog;

        /**
         * Sets the value of {@link AccessLogConfig#getVirtualGatewayAccessLog}
         * @param virtualGatewayAccessLog VirtualGateway CFN configuration for Access Logging.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder virtualGatewayAccessLog(software.amazon.awscdk.services.appmesh.CfnVirtualGateway.VirtualGatewayAccessLogProperty virtualGatewayAccessLog) {
            this.virtualGatewayAccessLog = virtualGatewayAccessLog;
            return this;
        }

        /**
         * Sets the value of {@link AccessLogConfig#getVirtualNodeAccessLog}
         * @param virtualNodeAccessLog VirtualNode CFN configuration for Access Logging.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder virtualNodeAccessLog(software.amazon.awscdk.services.appmesh.CfnVirtualNode.AccessLogProperty virtualNodeAccessLog) {
            this.virtualNodeAccessLog = virtualNodeAccessLog;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link AccessLogConfig}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public AccessLogConfig build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link AccessLogConfig}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements AccessLogConfig {
        private final software.amazon.awscdk.services.appmesh.CfnVirtualGateway.VirtualGatewayAccessLogProperty virtualGatewayAccessLog;
        private final software.amazon.awscdk.services.appmesh.CfnVirtualNode.AccessLogProperty virtualNodeAccessLog;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.virtualGatewayAccessLog = software.amazon.jsii.Kernel.get(this, "virtualGatewayAccessLog", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.appmesh.CfnVirtualGateway.VirtualGatewayAccessLogProperty.class));
            this.virtualNodeAccessLog = software.amazon.jsii.Kernel.get(this, "virtualNodeAccessLog", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.appmesh.CfnVirtualNode.AccessLogProperty.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.virtualGatewayAccessLog = builder.virtualGatewayAccessLog;
            this.virtualNodeAccessLog = builder.virtualNodeAccessLog;
        }

        @Override
        public final software.amazon.awscdk.services.appmesh.CfnVirtualGateway.VirtualGatewayAccessLogProperty getVirtualGatewayAccessLog() {
            return this.virtualGatewayAccessLog;
        }

        @Override
        public final software.amazon.awscdk.services.appmesh.CfnVirtualNode.AccessLogProperty getVirtualNodeAccessLog() {
            return this.virtualNodeAccessLog;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            if (this.getVirtualGatewayAccessLog() != null) {
                data.set("virtualGatewayAccessLog", om.valueToTree(this.getVirtualGatewayAccessLog()));
            }
            if (this.getVirtualNodeAccessLog() != null) {
                data.set("virtualNodeAccessLog", om.valueToTree(this.getVirtualNodeAccessLog()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@aws-cdk/aws-appmesh.AccessLogConfig"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            AccessLogConfig.Jsii$Proxy that = (AccessLogConfig.Jsii$Proxy) o;

            if (this.virtualGatewayAccessLog != null ? !this.virtualGatewayAccessLog.equals(that.virtualGatewayAccessLog) : that.virtualGatewayAccessLog != null) return false;
            return this.virtualNodeAccessLog != null ? this.virtualNodeAccessLog.equals(that.virtualNodeAccessLog) : that.virtualNodeAccessLog == null;
        }

        @Override
        public final int hashCode() {
            int result = this.virtualGatewayAccessLog != null ? this.virtualGatewayAccessLog.hashCode() : 0;
            result = 31 * result + (this.virtualNodeAccessLog != null ? this.virtualNodeAccessLog.hashCode() : 0);
            return result;
        }
    }
}
